Plugins
=======

.. automodule:: chancy.plugins
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   chancy.plugins.leadership
   chancy.plugins.pruner
   chancy.plugins.recovery
   chancy.plugins.cron
   chancy.plugins.api
   chancy.plugins.workflow
   chancy.plugins.retry